import type { ContextDefinition } from "jsonld"

export type OcCommunity = {
  '@id': string
  identifier: string
  name: string,
  title: LocalizedProperty
  description: LocalizedProperty
  abstract: LocalizedProperty
  logo: undefined | string
  color: undefined | string
  isSpaceOf: undefined | string
}

export type OcMemberInfos = {
  loginID: string,
  hasPrivateGraph: string,
  hasSystemGraph: string,
}

export type OcPerson = {
  '@id': string
  familyName: string
  givenName: string
  homepage: string
  description: string
  access: Array<string> | string
  mbox: Array<string> | string
  organization: Array<string> | string
  topic_interest: Array<string> | string
}

export type OcJsonLdDocument<T> = {
  graph: T[]
  context: ContextDefinition
}

export type OcTreeNode = {
  "@id": string
  "@type": string | string[]
  identifier: string | { '@type': string, '@value': string }
  title: { [locale: string]: string }
  description: LocalizedProperty
  type: string
  children: Array<OcTreeNode>
  catalog?: Array<OcTreeNode> | Array<string>
  dataset?: Array<OcTreeNode> | Array<string>
  distribution?: Array<OcTreeNode> | Array<string>
}

export type Credentials = {
  username: string
  password: string
}

export type HttpResponse = {
  status: number
  data: string
}

export type LocalizedProperty = undefined | { [locale: string]: string }

export type HomeAction = {
  id: string,
  title: { [locale: string]: string }
  description: { [locale: string]: string }
  fairBadges?: {
    f: boolean,
    a: boolean,
    i: boolean,
    r: boolean
  }
}
