import i18n from '@/i18n'
import {
  createRouter,
  createWebHistory,
} from 'vue-router'
import { routes } from 'vue-router/auto-routes'
import { useAccountStore } from './stores/account'
import { getProfileInfos } from './sparql/connection'
import type { Credentials } from './declarations'

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL ?? ''),
  routes: [
    {
      path: '/',
      redirect() {
        const language = navigator.language.split('-')[0] as typeof i18n.global.locale.value
        if (i18n.global.availableLocales.includes(language)) {
          return { path: `${language}` }
        } else {
          return { path: `${i18n.global.fallbackLocale}` }
        }
      },
    },
    ...routes,
  ],
})

/**
 * Configure i18n from the first slug of current route.
 */
router.beforeResolve((to) => {
  const language = (Array.isArray(to.params.lang) ? to.params.lang[0] : to.params.lang) as typeof i18n.global.locale.value

  if (i18n.global.availableLocales.includes(language)) {
    i18n.global.locale.value = language
  } else {
    return {
      name: `:lang/[...path]`,
      params: {
        lang: i18n.global.locale.value,
        path: 'error'
      },
      query: {
        code: 404,
        from: to.path
      }
    }
  }
})

/**
 * Handle authentification.
 */
router.beforeEach(async () => {
  const accountStore = useAccountStore()

  if (accountStore.isAuthenticated && accountStore.profile === null) {
    const { infos, profile } = await getProfileInfos(accountStore.auth as Credentials)

    accountStore.profile = profile
    accountStore.infos = infos
  }
})

export default router
