import { getMemberInfos, getMemberProfile } from "./members"
import { executeSparqlInsert } from "./sparql"
import type { Credentials } from "@/declarations"

export async function getProfileInfos(auth: Credentials) {
  const { graph: memberInfosList } = await getMemberInfos(auth)
  if (memberInfosList.length === 0) {
    throw new Error('No infos found for current user.')
  }
  const memberInfos = memberInfosList[0]

  const { graph: memberProfileList } = await getMemberProfile(memberInfos.hasPrivateGraph, auth)
  if (memberProfileList.length === 0) {
    throw new Error('No profile found for current user.')
  }
  const memberProfile = memberProfileList[0]

  return {
    infos: memberInfos,
    profile: memberProfile,
  }
}

export async function insertRegistrationRequest(login: string, firstName: string, givenName: string) {
  const uuid = crypto.randomUUID()

  return await executeSparqlInsert(
    `
    INSERT INTO <oct:visitors> {
      <https://www.irit.fr/opencommon/members/${uuid}> a foaf:Person;
                                                       oct:loginID '${login}';
                                                       dct:identifier '${uuid}';
                                                       foaf:givenName '${givenName}';
                                                       foaf:familyName '${firstName}'.
    }
    `,
    {
      asVisitor: true
    }
  )
}
