import { type OcPerson, type OcMemberInfos, type Credentials } from "@/declarations"
import { executeSparqlConstruct } from "./sparql"

/**
 * For a member, i.e. a connected user, get the IRI of their graphs (private & system).
 */
export const getMemberInfos = async (auth: Credentials) => {
  return await executeSparqlConstruct<OcMemberInfos>(
    `
      CONSTRUCT {?member ?p ?graph}
      WHERE {
        VALUES ?p { oct:hasSystemGraph oct:hasPrivateGraph oct:loginID}
        ?member ?p ?graph.
      }
    `,
    {
      auth: auth
    }
  )
}

/**
 * For a member, i.e. a connected user, get their profile.
 */
export const getMemberProfile = async (memberPrivateGraph: string, auth: Credentials) => {
  return await executeSparqlConstruct<OcPerson>(
    `
      WITH<${memberPrivateGraph}>
      CONSTRUCT { ?member ?p ?o. }
      WHERE {
        ?member a foaf:Person;
                ?p ?o.
      }
    `,
    {
      auth: auth
    }
  )
}
