import { type OcJsonLdDocument, type OcTreeNode, type Credentials } from '@/declarations'
import { executeSparqlConstruct } from './sparql'
import type { ContextDefinition } from 'jsonld'

/**
 * Get tree nodes from a parent node URI
 */
export const getTreeNodesFromParentNodeURI = async (
  parentNodeUri: string,
  auth?: Credentials
): Promise<OcJsonLdDocument<OcTreeNode>> => {
  const context: ContextDefinition = {
    catalog: {
      '@id': 'http://www.w3.org/ns/dcat#catalog',
      '@type': '@id',
      '@container': ['@set']
    },
    dataset: {
      '@id': 'http://www.w3.org/ns/dcat#dataset',
      '@type': '@id',
      '@container': ['@set']
    },
    distribution: {
      '@id': 'http://www.w3.org/ns/dcat#distribution',
      '@type': '@id',
      '@container': ['@set']
    },
    title: {
      '@id': 'http://purl.org/dc/terms/title',
      '@container': '@language'
    },
    identifier: {
      '@id': 'http://purl.org/dc/terms/identifier'
    }
  }

  const frame = {
    '@id': parentNodeUri,
    '@context': context,
    contains: {
      '@type': 'http://www.w3.org/ns/dcat#Catalog',
      '@embed': '@always',
      contains: {
        '@type': [
          'http://www.w3.org/ns/dcat#Catalog',
          'http://www.w3.org/ns/dcat#Dataset',
          'http://www.w3.org/ns/dcat#Distribution'
        ],
        '@embed': '@always'
      }
    }
  }

  return await executeSparqlConstruct<OcTreeNode>(
    `
        CONSTRUCT {<${parentNodeUri}> ?p ?o. ?node ?p2 ?o2}
        WHERE {
                VALUES ?p { dcat:catalog dcat:dataset dcat:distribution dct:title dct:identifier rdf:type }
                VALUES ?p2 { dcat:catalog dcat:dataset dcat:distribution dct:title dct:identifier rdf:type }
                <${parentNodeUri}> ?p ?o.
                <${parentNodeUri}> (dcat:catalog|dcat:dataset|dcat:distribution){0,1} ?node.
                ?node ?p2 ?o2
        }
    `,
    {
      context: context,
      auth: auth,
      frame: frame
    }
  )
}
