import type { Credentials, OcMemberInfos, OcPerson } from '@/declarations'
import { defineStore } from 'pinia'
import { computed, ref, watch } from 'vue'

interface AccountState {
  auth?: Credentials
  infos: OcMemberInfos | null
  profile: OcPerson | null
  isAuthenticated: boolean
}

export const useAccountStore = defineStore<string, AccountState>('account', () => {
  const auth = ref<Credentials>()

  const localAuth = localStorage.getItem('token')

  if (localAuth !== null) {
    const [username, password] = atob(localAuth).split(':')

    auth.value = {
      username: username,
      password: password,
    }
  }

  const infos = ref(null)
  const profile = ref(null)

  const isAuthenticated = computed(() => auth.value !== undefined)

  watch(auth, (auth: Credentials) => {
    if (auth) {
      localStorage.setItem("token", btoa(`${auth.username}:${auth.password}`));
    } else {
      localStorage.removeItem("token")
    }
  })

  return {
    auth,
    infos,
    profile,
    isAuthenticated
  }
})
