import type { OcCommunity } from '@/declarations'
import { getCommunityList } from '@/sparql/communities'
import { defineStore } from 'pinia'
import { computed, ref } from 'vue'

interface CommunityState {
  data: OcCommunity[]
  loading: boolean
  error: null | Error
}

export const useCommunityStore = defineStore('community', () => {
  const state = ref<CommunityState>({
    data: [],
    loading: false,
    error: null,
  })

  async function fetchIfEmpty(force: boolean = false) {
    if (force || state.value.data.length === 0) {
      state.value.loading = true
      try {
        const result = await getCommunityList();
        state.value.data = result.graph
      } catch (e) {
        state.value.error = e as Error
      }
      state.value.loading = false
    }
  }

  const getByName = computed(() => {
    return (name: string) => state.value.data.find((community) => community.name === name)
  })

  return {
    state,
    fetchIfEmpty,
    getByName,
  }
})
