import type { OcTreeNode } from '@/declarations'
import { getTreeNodesFromParentNodeURI } from '@/sparql/tree'
import { defineStore } from 'pinia'
import { ref } from 'vue'
import { useAccountStore } from './account'

const account = useAccountStore()

interface TreeState {
    data: OcTreeNode[]
    loading: boolean
    error: null | Error
}

export const homeNodeUri = "https://www.irit.fr/opencommon/resourceTree/Home"

export const useTreeStore = defineStore('tree', () => {
    const state = ref<TreeState>({
        data: [],
        loading: false,
        error: null,
    })

    async function fetchIfEmpty() {
        if (state.value.data.length == 0) {
            state.value.loading = true

            const result = await getTreeNodesFromParentNodeURI(homeNodeUri, account.auth)
            state.value.data = result.graph

            state.value.loading = false
        }
    }

    async function fetchTreeNodesFromParentNodeURI(parentNodeUri: string) {
        let parentNode = findNode(parentNodeUri, state.value.data[0])
        if (parentNode) {
            const result = await getTreeNodesFromParentNodeURI(parentNodeUri, account.auth)
            parentNode = Object.assign(parentNode, result.graph[0])
        }
    }

    function findNode(nodeUri: string, currentNode: OcTreeNode): OcTreeNode | false {
        let result: OcTreeNode | false

        if (nodeUri == currentNode['@id']) {
            return currentNode;
        } else {
            if (currentNode.catalog) {
                for (let i = 0; i < currentNode.catalog.length; i += 1) {
                    if (typeof currentNode.catalog[i] !== "string") {
                        result = findNode(nodeUri, currentNode.catalog[i] as OcTreeNode);

                        if (result !== false) {
                            return result;
                        }
                    }
                }
            }

            if (currentNode.dataset) {
                for (let i = 0; i < currentNode.dataset.length; i += 1) {
                    if (typeof currentNode.dataset[i] !== "string") {
                        result = findNode(nodeUri, currentNode.dataset[i] as OcTreeNode);

                        if (result !== false) {
                            return result;
                        }
                    }
                }
            }

            if (currentNode.distribution) {
                for (let i = 0; i < currentNode.distribution.length; i += 1) {
                    if (typeof currentNode.distribution[i] !== "string") {
                        result = findNode(nodeUri, currentNode.distribution[i] as OcTreeNode);

                        if (result !== false) {
                            return result;
                        }
                    }
                }
            }
            return false;
        }
    }


    return {
        state,
        fetchIfEmpty,
        fetchTreeNodesFromParentNodeURI
    }
})
